@@ -77,7 +77,12 @@ class MxTreeView(QTreeView):
         self.activated.connect(self.activated_callback)
         # self.doubleClicked.connect(self.doubleClicked_callback)
 
+        self.mx_widget = parent.mx_widget
         self.plugin = parent.plugin
+        if spyder.version_info > (5,):
+            self.container = self.plugin.get_container()
+        else:
+            self.container = self.plugin
         self.shell = None
         self.reply = None  # To write dialog box result
         self.setAlternatingRowColors(False)
@@ -298,7 +303,7 @@ class MxTreeView(QTreeView):
                 self.reply = None
 
         elif action == self.action_read_model:
-            dialog = ReadModelDialog(self)
+            dialog = ReadModelDialog(self, modelpath=self.mx_widget.last_modelpath)
             dialog.exec()
 
             if self.reply['accepted']:
@@ -311,16 +316,17 @@ class MxTreeView(QTreeView):
                     varname = ''
                 self.reply = None
                 self.shell.read_model(modelpath, name, define_var, varname)
+                self.mx_widget.last_modelpath = modelpath
             else:
                 self.reply = None
 
         elif action == self.action_write_model:
-            model = self.plugin.current_widget().model_selector.get_selected_model()
+            model = self.container.current_widget().model_selector.get_selected_model()
             if not model:
                 QMessageBox.critical(self, "Error", "No model exits.")
                 return
 
-            dialog = WriteModelDialog(self)
+            dialog = WriteModelDialog(self, modelpath=self.mx_widget.last_modelpath)
             dialog.exec()
 
             if self.reply['accepted']:
@@ -329,11 +335,12 @@ class MxTreeView(QTreeView):
                 zipmodel = self.reply['zipmodel']
                 self.reply = None
                 self.shell.write_model(model, modelpath, backup, zipmodel)
+                self.mx_widget.last_modelpath = modelpath
             else:
                 self.reply = None
 
         elif action == self.action_delete_model:
-            model = self.plugin.current_widget().model_selector.get_selected_model()
+            model = self.container.current_widget().model_selector.get_selected_model()
             if model:
                 answer = QMessageBox.question(
                     self, _("Delete Model"),
@@ -355,7 +362,7 @@ class MxTreeView(QTreeView):
                     if index.parent().isValid():
                         parent = index.parent().internalPointer().fullname
                     else:
-                        parent = self.plugin.current_widget().model_selector.get_selected_model()
+                        parent = self.container.current_widget().model_selector.get_selected_model()
                     assert parent
 
                     answer = QMessageBox.question(
@@ -377,6 +384,7 @@ class MxExplorer(QWidget):
     def __init__(self, parent):
         QWidget.__init__(self, parent)
 
+        self.mx_widget = parent
         self.plugin = parent.plugin
         self.setWindowTitle("Mx explorer") # Not visible
 
@@ -403,82 +411,152 @@ class MxExplorer(QWidget):
             self.treeview.setModel(None)
 
 
-class MxMainWidget(MxToolBarMixin, QWidget):
+if spyder.version_info > (5,):
 
-    def __init__(self, parent, **kwargs):
-        QWidget.__init__(self, parent)
+    class MxMainWidget(QWidget):
 
-        self.plugin = parent
+        def __init__(self, parent, **kwargs):
 
-        # Create tool bar
-        if "options_button" in kwargs:
-            self.options_button = kwargs["options_button"]
-        else:
-            self.options_button = None
-        self.plugin_actions = []
-        MxToolBarMixin.__init__(
-            self,
-            options_button=self.options_button,
-            plugin_actions=self.plugin_actions
-        )
+            QWidget.__init__(self, parent)
+            self.plugin = parent.get_plugin()
+            self.last_modelpath = None
 
-        # Create widget and add to dockwindow
-        self.explorer = MxExplorer(self)
+            # Create and place Model Selector
+            txt = _("Model")
+            if sys.platform == 'darwin':
+                expr_label = QLabel("  " + txt)
+            else:
+                expr_label = QLabel(txt)
 
-        # Create code list
-        self.codelist = MxCodeListWidget(self)
-        self.propwidget = MxPropertyWidget(self, orientation=Qt.Vertical)
+            # expr_label.setAlignment(Qt.AlignCenter | Qt.AlignRight)
+            self.model_selector = MxModelSelector(self)
+            selector_layout = QHBoxLayout()
+            selector_layout.addWidget(expr_label)
+            selector_layout.addWidget(self.model_selector)
+            selector_layout.insertStretch(-1, 1)
+            selector_layout.setStretch(0, 0)
+            selector_layout.setStretch(1, 1)
 
-        # Create splitter
-        self.splitter = QSplitter(self)
-        self.splitter.setContentsMargins(0, 0, 0, 0)
-        # self.splitter.addWidget(self.widget)
-        # self.splitter.setStretchFactor(0, 5)
-        # self.splitter.setStretchFactor(1, 1)
+            # Create widget and add to dockwindow
+            self.explorer = MxExplorer(self)
 
-        self.tabwidget = QTabWidget(parent=self)
-        # self.tabwidget.setContentsMargins(0, 0, 0, 0)
-        MxMainWidget.IdxProperties = self.tabwidget.addTab(self.propwidget, "Properties")
-        MxMainWidget.IdxFormulas = self.tabwidget.addTab(self.codelist, "Formulas")
+            # Create code list
+            self.codelist = MxCodeListWidget(self)
+            self.propwidget = MxPropertyWidget(self, orientation=Qt.Vertical)
 
-        # Layout management
-        self.splitter.addWidget(self.explorer)
-        self.splitter.addWidget(self.tabwidget)
+            # Create splitter
+            self.splitter = QSplitter(self)
+            self.splitter.setContentsMargins(0, 0, 0, 0)
+            # self.splitter.addWidget(self.widget)
+            # self.splitter.setStretchFactor(0, 5)
+            # self.splitter.setStretchFactor(1, 1)
 
-        layout = create_plugin_layout(self.tools_layout, self.splitter)
+            self.tabwidget = QTabWidget(parent=self)
+            # self.tabwidget.setContentsMargins(0, 0, 0, 0)
+            MxMainWidget.IdxProperties = self.tabwidget.addTab(self.propwidget, "Properties")
+            MxMainWidget.IdxFormulas = self.tabwidget.addTab(self.codelist, "Formulas")
 
-        self.setFocusPolicy(Qt.ClickFocus)
-        self.setLayout(layout)
+            # Layout management
+            self.splitter.addWidget(self.explorer)
+            self.splitter.addWidget(self.tabwidget)
 
-    def set_shellwidget(self, shellwidget):
-        """Bind shellwidget instance to namespace browser"""
-        self.shellwidget = shellwidget
-        self.shellwidget.set_mxexplorer(self.explorer, self.model_selector)
-        self.shellwidget.set_mxcodelist(self.codelist)
-        self.shellwidget.set_mxproperty(self.propwidget)
+            layout = create_plugin_layout(selector_layout, self.splitter)
+            self.setLayout(layout)
 
-    def raise_tab(self, widget):
-        self.tabwidget.setCurrentWidget(widget)
+            self.setFocusPolicy(Qt.ClickFocus)
 
-    # MxToolBarMixin interface method
-    def setup_toolbar(self):
 
-        txt = _("Model")
-        if sys.platform == 'darwin':
-            expr_label = QLabel("  " + txt)
-        else:
-            expr_label = QLabel(txt)
+        def set_shellwidget(self, shellwidget):
+            """Bind shellwidget instance to namespace browser"""
+            self.shellwidget = shellwidget
+            self.shellwidget.set_mxexplorer(self.explorer, self.model_selector)
+            self.shellwidget.set_mxcodelist(self.codelist)
+            self.shellwidget.set_mxproperty(self.propwidget)
 
-        expr_label.setAlignment(Qt.AlignCenter | Qt.AlignRight)
+        def raise_tab(self, widget):
+            self.tabwidget.setCurrentWidget(widget)
 
-        if spyder.version_info < (4,):
-            font = self.plugin.get_plugin_font()
-        else:
-            font = self.plugin.get_font()
+else:
+    class MxMainWidget(MxToolBarMixin, QWidget):
 
-        self.model_selector = MxModelSelector(self)
+        def __init__(self, parent, **kwargs):
+            QWidget.__init__(self, parent)
 
-        return [expr_label, self.model_selector]
+            if spyder.version_info > (5,):
+                self.plugin = parent.get_plugin()
+            else:
+                self.plugin = parent
+            self.last_modelpath = None
+
+            # Create tool bar
+            if "options_button" in kwargs:
+                self.options_button = kwargs["options_button"]
+            else:
+                self.options_button = None
+            self.plugin_actions = []
+            MxToolBarMixin.__init__(
+                self,
+                options_button=self.options_button,
+                plugin_actions=self.plugin_actions
+            )
+
+            # Create widget and add to dockwindow
+            self.explorer = MxExplorer(self)
+
+            # Create code list
+            self.codelist = MxCodeListWidget(self)
+            self.propwidget = MxPropertyWidget(self, orientation=Qt.Vertical)
+
+            # Create splitter
+            self.splitter = QSplitter(self)
+            self.splitter.setContentsMargins(0, 0, 0, 0)
+            # self.splitter.addWidget(self.widget)
+            # self.splitter.setStretchFactor(0, 5)
+            # self.splitter.setStretchFactor(1, 1)
+
+            self.tabwidget = QTabWidget(parent=self)
+            # self.tabwidget.setContentsMargins(0, 0, 0, 0)
+            MxMainWidget.IdxProperties = self.tabwidget.addTab(self.propwidget, "Properties")
+            MxMainWidget.IdxFormulas = self.tabwidget.addTab(self.codelist, "Formulas")
+
+            # Layout management
+            self.splitter.addWidget(self.explorer)
+            self.splitter.addWidget(self.tabwidget)
+
+            layout = create_plugin_layout(self.tools_layout, self.splitter)
+
+            self.setFocusPolicy(Qt.ClickFocus)
+            self.setLayout(layout)
+
+        def set_shellwidget(self, shellwidget):
+            """Bind shellwidget instance to namespace browser"""
+            self.shellwidget = shellwidget
+            self.shellwidget.set_mxexplorer(self.explorer, self.model_selector)
+            self.shellwidget.set_mxcodelist(self.codelist)
+            self.shellwidget.set_mxproperty(self.propwidget)
+
+        def raise_tab(self, widget):
+            self.tabwidget.setCurrentWidget(widget)
+
+        # MxToolBarMixin interface method
+        def setup_toolbar(self):
+
+            txt = _("Model")
+            if sys.platform == 'darwin':
+                expr_label = QLabel("  " + txt)
+            else:
+                expr_label = QLabel(txt)
+
+            expr_label.setAlignment(Qt.AlignCenter | Qt.AlignRight)
+
+            if spyder.version_info < (4,):
+                font = self.plugin.get_plugin_font()
+            else:
+                font = self.plugin.get_font()
+
+            self.model_selector = MxModelSelector(self)
+
+            return [expr_label, self.model_selector]
 
 
 class MxModelSelector(QComboBox):
@@ -676,7 +754,7 @@ class NewModelDialog(QDialog):
 
 class ReadModelDialog(QDialog):
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, modelpath=None):
         QDialog.__init__(
             self, parent, flags=Qt.WindowSystemMenuHint | Qt.WindowTitleHint)
         self.setWindowTitle('Read Model')
@@ -696,6 +774,9 @@ class ReadModelDialog(QDialog):
         fixed_dir_layout.addWidget(openzip_btn)
         fixed_dir_layout.setContentsMargins(0, 0, 0, 0)
 
+        if modelpath:
+            self.wd_edit.setText(modelpath)
+
         namelabel = QLabel(_("Model Name"))
         self.nameEdit = QLineEdit(self)
         self.importWidget = ImportAsWidget(self, self.nameEdit)
@@ -761,7 +842,7 @@ class ReadModelDialog(QDialog):
 
 class WriteModelDialog(QDialog):
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, modelpath=None):
         QDialog.__init__(
             self, parent, flags=Qt.WindowSystemMenuHint | Qt.WindowTitleHint)
         self.setWindowTitle('Write Model')
@@ -783,6 +864,12 @@ class WriteModelDialog(QDialog):
         namelabel = QLabel(_("Folder/File"))
         self.nameEdit = QLineEdit(self)
 
+        if modelpath:
+            location = "/".join(modelpath.split("/")[:-1])
+            name = modelpath.split("/")[-1]
+            self.wd_edit.setText(location)
+            self.nameEdit.setText(name)
+
         self.backupCheck = QCheckBox(_("Back up old folder"))
         self.backupCheck.setCheckState(Qt.Checked)
 
